import type { AccountId } from "../models/AccountId";
import type { DeleteFileBatchRequestV2 } from "../models/DeleteFileBatchRequestV2";
import type { FileDetails } from "../models/FileDetails";
import type { FilePath } from "../models/FilePath";
export declare class FilesV2Service {
    /**
     * Gets the full metadata for a file. Required API key type: 'secret_*' or 'public_*'.
     * @param accountId
     * @param filePath
     * @returns FileDetails Success.
     * @throws ApiError
     */
    static getFileDetails(accountId: AccountId, filePath: FilePath): Promise<FileDetails>;
    /**
     * Synchronously deletes a file. Required API key type: 'secret_*' only.
     * @param accountId
     * @param filePath
     * @returns any Success.
     * @throws ApiError
     */
    static deleteFile(accountId: AccountId, filePath: FilePath): Promise<any>;
    /**
     * Asynchronously deletes multiple files. Required API key type: 'secret_*' only.
     * @param accountId
     * @param requestBody
     * @returns void
     * @throws ApiError
     */
    static deleteFileBatch(accountId: AccountId, requestBody: DeleteFileBatchRequestV2): Promise<void>;
}
