import type { AccountId } from "../models/AccountId";
import type { AccountJobId } from "../models/AccountJobId";
import type { AccountJobType } from "../models/AccountJobType";
import type { JobSummary } from "../models/JobSummary";
import type { ListRecentJobsResponse } from "../models/ListRecentJobsResponse";
export declare class JobsService {
    /**
     * Gets information on a job in any state. Required API key type: 'secret_*' only.
     * @param accountId
     * @param jobType
     * @param jobId
     * @returns JobSummary Success.
     * @throws ApiError
     */
    static getJob(accountId: AccountId, jobType: AccountJobType, jobId: AccountJobId): Promise<JobSummary>;
    /**
     * Cancels an in-progress job. Required API key type: 'secret_*' only.
     * @param accountId
     * @param jobType
     * @param jobId
     * @returns any Success.
     * @throws ApiError
     */
    static cancelJob(accountId: AccountId, jobType: AccountJobType, jobId: AccountJobId): Promise<any>;
    /**
     * Lists the most recently issued jobs. Required API key type: 'secret_*' only.
     * @param accountId
     * @param jobType1
     * @param jobType2
     * @returns ListRecentJobsResponse Success.
     * @throws ApiError
     */
    static listRecentJobs(accountId: AccountId, jobType1: AccountJobType, jobType2?: AccountJobType): Promise<ListRecentJobsResponse>;
}
