/* istanbul ignore file */
/* tslint:disable */
/* eslint-disable */
import type { AccountId } from "../models/AccountId";
import type { AccountJobId } from "../models/AccountJobId";
import type { AccountJobType } from "../models/AccountJobType";
import type { JobSummary } from "../models/JobSummary";
import type { ListRecentJobsResponse } from "../models/ListRecentJobsResponse";
import { request as __request } from "../core/request";

export class JobsService {
  /**
   * Gets information on a job in any state. Required API key type: 'secret_*' only.
   * @param accountId
   * @param jobType
   * @param jobId
   * @returns JobSummary Success.
   * @throws ApiError
   */
  public static async getJob(accountId: AccountId, jobType: AccountJobType, jobId: AccountJobId): Promise<JobSummary> {
    const result = await __request({
      method: "GET",
      path: `/v2/accounts/${accountId}/jobs/${jobType}/${jobId}`,
      errors: {
        401: `Unauthenticated.`
      }
    });
    return result.body;
  }

  /**
   * Cancels an in-progress job. Required API key type: 'secret_*' only.
   * @param accountId
   * @param jobType
   * @param jobId
   * @returns any Success.
   * @throws ApiError
   */
  public static async cancelJob(accountId: AccountId, jobType: AccountJobType, jobId: AccountJobId): Promise<any> {
    const result = await __request({
      method: "DELETE",
      path: `/v2/accounts/${accountId}/jobs/${jobType}/${jobId}`,
      errors: {
        401: `Unauthenticated.`
      }
    });
    return result.body;
  }

  /**
   * Lists the most recently issued jobs. Required API key type: 'secret_*' only.
   * @param accountId
   * @param jobType1
   * @param jobType2
   * @returns ListRecentJobsResponse Success.
   * @throws ApiError
   */
  public static async listRecentJobs(
    accountId: AccountId,
    jobType1: AccountJobType,
    jobType2?: AccountJobType
  ): Promise<ListRecentJobsResponse> {
    const result = await __request({
      method: "GET",
      path: `/v2/accounts/${accountId}/jobs`,
      query: {
        jobType1: jobType1,
        jobType2: jobType2
      },
      errors: {
        401: `Unauthenticated.`
      }
    });
    return result.body;
  }
}
